==> dialog_pp_flutter-0.0.2.tar.gz: lib/untitled.dart <==
import 'package:assets_audio_player/assets_audio_player.dart';
import 'package:external_app_launcher/external_app_launcher.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:get/get.dart';
import 'package:lottie/lottie.dart';
import 'package:package_info_plus/package_info_plus.dart';

import 'get_controller.dart';

class PPDialog {
  static updateDialog(
    BuildContext context, {
    required bool isPopupRequired,
    required bool isPopup,
    required int apiVersionCode,
    required String appLogoApi,
    required String appNameApi,
    required String subtitleAppApi,
    required String appWebsiteUrl,
  }) async {
    if ((isPopup == true &&
        (apiVersionCode) > int.parse(AppDetailsPP.to.buildNumber.value))) {
      AssetsAudioPlayer.newPlayer().open(
        Audio("packages/untitled/assets/dialogs_assets/music.wav"),
        autoStart: true,
        showNotification: false,
      );

      Get.defaultDialog(
          onWillPop: () async {
            if (isPopupRequired == true) {
              return false;
            } else {
              return true;
            }
          },
          barrierDismissible: isPopupRequired == true ? false : true,
          title: "",
          content: Stack(
            children: [
              Column(
                children: [
                  Row(
                    mainAxisAlignment: MainAxisAlignment.center,
                    crossAxisAlignment: CrossAxisAlignment.center,
                    children: [
                      Align(
                        alignment: Alignment.topRight,
                        child: Lottie.asset(
                            "packages/untitled/assets/dialogs_assets/bell.json",
                            height: 70.h),
                      ),
                      Text(
                        "Alert".tr,
                        style: TextStyle(
                            fontSize: 24.w, fontWeight: FontWeight.bold),
                      ),
                      const Text(
                        " (Ad)",
                        style: TextStyle(color: Colors.grey),
                      ),
                    ],
                  ),
                  const SizedBox(
                    height: 20,
                  ),
                  if (appLogoApi.isEmpty)
                    Container(
                      decoration: const BoxDecoration(
                          borderRadius: BorderRadius.all(Radius.circular(20))),
                      child: Container(
                        decoration: const BoxDecoration(
                            borderRadius:
                                BorderRadius.all(Radius.circular(20))),
                        child: Image.asset(
                          "packages/untitled/assets/dialogs_assets/playstore.png",
                          height: 250.h,
                        ),
                      ),
                    )
                  else
                    Container(
                      decoration: BoxDecoration(
                        borderRadius:
                            const BorderRadius.all(Radius.circular(30)),
                        boxShadow: [
                          BoxShadow(
                            color: Colors.black.withOpacity(0.3),
                            spreadRadius: 2,
                            blurRadius: 5,
                            offset: const Offset(
                                4, 10), // changes position of shadow
                          ),
                        ],
                      ),
                      child: ClipRRect(
                        borderRadius:
                            const BorderRadius.all(Radius.circular(30)),
                        child: InkWell(
                          onTap: () async {
                            DialogGetController.to.noThankButton.value = true;

                            var packageid = appWebsiteUrl.split("?id=");

                            await LaunchApp.openApp(
                                androidPackageName: packageid[1],
                                iosUrlScheme: 'pulsesecure://',
                                appStoreLink:
                                    'itms-apps://itunes.apple.com/us/app/pulse-secure/id945832041');
                            // launch(appWebsiteUrl);
                          },
                          child: Image.network(
                            appLogoApi,
                            fit: BoxFit.fill,
                            height: 190.h,
                            width: 190.h,
                          ),
                        ),
                      ),
                    ),
                ],
              ),
            ],
          ),
          actions: [
            Column(
              children: [
                SizedBox(
                  height: 20.h,
                ),
                Text(appNameApi.tr,
                    style: const TextStyle(
                        color: Colors.black, fontWeight: FontWeight.bold)),
                SizedBox(
                  height: 10.h,
                ),
                Text(subtitleAppApi.tr, textAlign: TextAlign.center),
                SizedBox(
                  height: 5.h,
                )
              ],
            )
          ],
          backgroundColor: Colors.white,
          titleStyle: const TextStyle(
              color: Colors.black, fontWeight: FontWeight.bold, height: 00),
          middleTextStyle: const TextStyle(
            color: Colors.white,
          ),
          confirm: Padding(
            padding: EdgeInsets.only(bottom: 10.h),
            child: Stack(
              children: [
                Row(
                  mainAxisAlignment: MainAxisAlignment.center,
                  crossAxisAlignment: CrossAxisAlignment.center,
                  children: [
                    isPopupRequired == false
                        ? InkWell(
                            onTap: () {
                              Get.back();
                            },
                            child: Text(
                              "No Thanks".tr,
                              style: const TextStyle(
                                  color: Color(0xff007A3D),
                                  fontWeight: FontWeight.bold),
                            ),
                          )
                        : Obx(
                            () => DialogGetController.to.noThankButton.value ==
                                    true
                                ? Padding(
                                    padding: EdgeInsets.only(right: 30.w),
                                    child: InkWell(
                                      onTap: () {
                                        Get.back();
                                      },
                                      child: Text(
                                        "No Thanks".tr,
                                        style: const TextStyle(
                                            color: Color(0xff007A3D),
                                            fontWeight: FontWeight.bold),
                                      ),
                                    ),
                                  )
                                : Container(),
                          ),
                    SizedBox(
                      width: isPopupRequired == true ? 0.w : 30.w,
                    ),
                    Container(
                      height: 50.h,
                      decoration: const BoxDecoration(
                        borderRadius: BorderRadius.all(Radius.circular(20)),
                      ),
                      width: 150.w,
                      child: Row(
                        children: [
                          InkWell(
                            child: Container(
                              width: 150.w,
                              height: 50.h,
                              decoration: const BoxDecoration(
                                image: DecorationImage(
                                  image: AssetImage(
                                      "packages/untitled/assets/dialogs_assets/playstore.png"),
                                  fit: BoxFit.fitWidth,
                                  alignment: Alignment.topCenter,
                                ),
                              ),
                            ),
                            onTap: () async {
                              DialogGetController.to.noThankButton.value = true;

                              var packageid = appWebsiteUrl.split("?id=");

                              await LaunchApp.openApp(
                                  androidPackageName: packageid[1],
                                  iosUrlScheme: 'pulsesecure://',
                                  appStoreLink:
                                      'itms-apps://itunes.apple.com/us/app/pulse-secure/id945832041');
                            },
                          )
                        ],
                      ),
                    ),
                    SizedBox(
                      height: 20.h,
                    )
                  ],
                ),
              ],
            ),
          ),
          // confirm: Container(
          //   child: Text("Download App"),
          // ),
          radius: 10);
    }
  }

  static newVersionCode() async {
    WidgetsFlutterBinding.ensureInitialized();
    PackageInfo packageInfo = await PackageInfo.fromPlatform();
    AppDetailsPP.to.appName.value = packageInfo.appName;
    AppDetailsPP.to.packageName.value = packageInfo.packageName;
    AppDetailsPP.to.versionApp.value = packageInfo.version;
    AppDetailsPP.to.buildNumber.value = packageInfo.buildNumber;
  }
}

==> dialog_pp_flutter-0.0.3.tar.gz: lib/untitled.dart <==
import 'package:assets_audio_player/assets_audio_player.dart';
import 'package:external_app_launcher/external_app_launcher.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:get/get.dart';
import 'package:lottie/lottie.dart';
import 'package:package_info_plus/package_info_plus.dart';

import 'get_controller.dart';

class PPDialog {
  static updateDialog(
    BuildContext context, {
    required bool isPopupRequired,
    required bool isPopup,
    required int apiVersionCode,
    required String appLogoApi,
    required String appNameApi,
    required String subtitleAppApi,
    required String appWebsiteUrl,
  }) async {
    if ((isPopup == true &&
        (apiVersionCode) > int.parse(AppDetailsPP.to.buildNumber.value))) {
      AssetsAudioPlayer.newPlayer().open(
        Audio("packages/dialog_pp_flutter/assets/dialogs_assets/music.wav"),
        autoStart: true,
        showNotification: false,
      );

      Get.defaultDialog(
          onWillPop: () async {
            if (isPopupRequired == true) {
              return false;
            } else {
              return true;
            }
          },
          barrierDismissible: isPopupRequired == true ? false : true,
          title: "",
          content: Stack(
            children: [
              Column(
                children: [
                  Row(
                    mainAxisAlignment: MainAxisAlignment.center,
                    crossAxisAlignment: CrossAxisAlignment.center,
                    children: [
                      Align(
                        alignment: Alignment.topRight,
                        child: Lottie.asset(
                            "packages/dialog_pp_flutter/assets/dialogs_assets/bell.json",
                            height: 70.h),
                      ),
                      Text(
                        "Alert".tr,
                        style: TextStyle(
                            fontSize: 24.w, fontWeight: FontWeight.bold),
                      ),
                      const Text(
                        " (Ad)",
                        style: TextStyle(color: Colors.grey),
                      ),
                    ],
                  ),
                  const SizedBox(
                    height: 20,
                  ),
                  if (appLogoApi.isEmpty)
                    Container(
                      decoration: const BoxDecoration(
                          borderRadius: BorderRadius.all(Radius.circular(20))),
                      child: Container(
                        decoration: const BoxDecoration(
                            borderRadius:
                                BorderRadius.all(Radius.circular(20))),
                        child: Image.asset(
                          "packages/dialog_pp_flutter/assets/dialogs_assets/playstore.png",
                          height: 250.h,
                        ),
                      ),
                    )
                  else
                    Container(
                      decoration: BoxDecoration(
                        borderRadius:
                            const BorderRadius.all(Radius.circular(30)),
                        boxShadow: [
                          BoxShadow(
                            color: Colors.black.withOpacity(0.3),
                            spreadRadius: 2,
                            blurRadius: 5,
                            offset: const Offset(
                                4, 10), // changes position of shadow
                          ),
                        ],
                      ),
                      child: ClipRRect(
                        borderRadius:
                            const BorderRadius.all(Radius.circular(30)),
                        child: InkWell(
                          onTap: () async {
                            DialogGetController.to.noThankButton.value = true;

                            var packageid = appWebsiteUrl.split("?id=");

                            await LaunchApp.openApp(
                                androidPackageName: packageid[1],
                                iosUrlScheme: 'pulsesecure://',
                                appStoreLink:
                                    'itms-apps://itunes.apple.com/us/app/pulse-secure/id945832041');
                            // launch(appWebsiteUrl);
                          },
                          child: Image.network(
                            appLogoApi,
                            fit: BoxFit.fill,
                            height: 190.h,
                            width: 190.h,
                          ),
                        ),
                      ),
                    ),
                ],
              ),
            ],
          ),
          actions: [
            Column(
              children: [
                SizedBox(
                  height: 20.h,
                ),
                Text(appNameApi.tr,
                    style: const TextStyle(
                        color: Colors.black, fontWeight: FontWeight.bold)),
                SizedBox(
                  height: 10.h,
                ),
                Text(subtitleAppApi.tr, textAlign: TextAlign.center),
                SizedBox(
                  height: 5.h,
                )
              ],
            )
          ],
          backgroundColor: Colors.white,
          titleStyle: const TextStyle(
              color: Colors.black, fontWeight: FontWeight.bold, height: 00),
          middleTextStyle: const TextStyle(
            color: Colors.white,
          ),
          confirm: Padding(
            padding: EdgeInsets.only(bottom: 10.h),
            child: Stack(
              children: [
                Row(
                  mainAxisAlignment: MainAxisAlignment.center,
                  crossAxisAlignment: CrossAxisAlignment.center,
                  children: [
                    isPopupRequired == false
                        ? InkWell(
                            onTap: () {
                              Get.back();
                            },
                            child: Text(
                              "No Thanks".tr,
                              style: const TextStyle(
                                  color: Color(0xff007A3D),
                                  fontWeight: FontWeight.bold),
                            ),
                          )
                        : Obx(
                            () => DialogGetController.to.noThankButton.value ==
                                    true
                                ? Padding(
                                    padding: EdgeInsets.only(right: 30.w),
                                    child: InkWell(
                                      onTap: () {
                                        Get.back();
                                      },
                                      child: Text(
                                        "No Thanks".tr,
                                        style: const TextStyle(
                                            color: Color(0xff007A3D),
                                            fontWeight: FontWeight.bold),
                                      ),
                                    ),
                                  )
                                : Container(),
                          ),
                    SizedBox(
                      width: isPopupRequired == true ? 0.w : 30.w,
                    ),
                    Container(
                      height: 50.h,
                      decoration: const BoxDecoration(
                        borderRadius: BorderRadius.all(Radius.circular(20)),
                      ),
                      width: 150.w,
                      child: Row(
                        children: [
                          InkWell(
                            child: Container(
                              width: 150.w,
                              height: 50.h,
                              decoration: const BoxDecoration(
                                image: DecorationImage(
                                  image: AssetImage(
                                      "packages/dialog_pp_flutter/assets/dialogs_assets/playstore.png"),
                                  fit: BoxFit.fitWidth,
                                  alignment: Alignment.topCenter,
                                ),
                              ),
                            ),
                            onTap: () async {
                              DialogGetController.to.noThankButton.value = true;

                              var packageid = appWebsiteUrl.split("?id=");

                              await LaunchApp.openApp(
                                  androidPackageName: packageid[1],
                                  iosUrlScheme: 'pulsesecure://',
                                  appStoreLink:
                                      'itms-apps://itunes.apple.com/us/app/pulse-secure/id945832041');
                            },
                          )
                        ],
                      ),
                    ),
                    SizedBox(
                      height: 20.h,
                    )
                  ],
                ),
              ],
            ),
          ),
          // confirm: Container(
          //   child: Text("Download App"),
          // ),
          radius: 10);
    }
  }

  static newVersionCode() async {
    WidgetsFlutterBinding.ensureInitialized();
    PackageInfo packageInfo = await PackageInfo.fromPlatform();
    AppDetailsPP.to.appName.value = packageInfo.appName;
    AppDetailsPP.to.packageName.value = packageInfo.packageName;
    AppDetailsPP.to.versionApp.value = packageInfo.version;
    AppDetailsPP.to.buildNumber.value = packageInfo.buildNumber;
  }
}
